@@ -24,6 +24,8 @@ p = ggplot(cities, aes(long, lat)) +
   scale_colour_manual(values = c("grey50", "red")) +
   # 设定线条尺寸：
   scale_size(range = c(1, 10)) +
+  # 设置坐标轴标签：
+  labs(x = "经度", y = "纬度") +
   # 隐藏图例设置：
   theme(legend.position = "none") +
   # 设定横轴范围：
