@@ -1,7 +1,7 @@
 # ggplot2 绘制世界各国农业进出口竞争力地图
 source(system.file("extdata", "AgriComp.R", package = "MSG"))
 library(ggplot2)
-worldmap = map_data("world")
+worldmap = ggplot2::map_data("world")
 worldmap2 = dplyr::left_join(worldmap, AgriComp,
                               by = c("region" = "Country"))
 p = ggplot(worldmap2) +
