@@ -2,12 +2,16 @@
 library(ggplot2)
 library(patchwork)
 data(tvearn, package = "MSG")
+levels(tvearn$gender) = c("女性", "男性")
+levels(tvearn$type) = c("喜剧", "正剧")
 dh1 = ggplot(aes(x = pay), data = tvearn) +
   geom_histogram(binwidth = 20000) +
+  labs(x = "薪酬", y = "频数") +
   facet_grid(gender ~ .)
 dh2 = ggplot(aes(x = rating, y = pay, color = type), data = tvearn) +
   geom_jitter() +
   geom_smooth(method = "loess") +
+  labs(x = "评分", y = "薪酬", color = "类型") +
   scale_y_continuous(
     labels = scales::unit_format(unit = "w", scale = 1e-4),
     breaks = seq(0, 125, 15) * 10^4) +
